# geosci


[![image](https://img.shields.io/pypi/v/geosci.svg)](https://pypi.python.org/pypi/geosci)
[![image](https://colab.research.google.com/assets/colab-badge.svg)](https://gishub.org/geosci-colab)
[![image](https://binder.pangeo.io/badge_logo.svg)](https://binder.pangeo.io/v2/gh/giswqs/geosci/master)
[![image](https://img.shields.io/conda/vn/conda-forge/geosci.svg)](https://anaconda.org/conda-forge/geosci)
<!-- [![image](https://pepy.tech/badge/geosci)](https://pepy.tech/project/geosci) -->
<!-- [![image](https://github.com/giswqs/geosci/workflows/docs/badge.svg)](https://geosci.org) -->
<!-- [![image](https://github.com/giswqs/geosci/workflows/build/badge.svg)](https://github.com/giswqs/geosci/actions?query=workflow%3Abuild) -->
[![Language grade: Python](https://img.shields.io/lgtm/grade/python/g/giswqs/geosci.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/giswqs/geosci/context:python)
[![image](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)


**A Python package for interactive mapping**


-   Free software: MIT license
-   Documentation: https://coliaxu.github.io/geosci
    

## Features

-   TODO

## Credits

This package was created with [Cookiecutter](https://github.com/cookiecutter/cookiecutter) and the [giswqs/pypackage](https://github.com/giswqs/pypackage) project template.
